.. tszip documentation master file, created by
   sphinx-quickstart on Fri May 10 12:36:03 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tszip's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   installation
   python-api
   cli
   development
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
